@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use autodie;
 
-our $VERSION = '0.04_02'; # TRIAL VERSION
+our $VERSION = '0.04_03'; # TRIAL VERSION
 
 use Exporter;
 use parent 'Exporter';
@@ -243,7 +243,7 @@ Date::Easy::Date - easy date class
 
 =head1 VERSION
 
-This document describes version 0.04_02 of Date::Easy::Date.
+This document describes version 0.04_03 of Date::Easy::Date.
 
 =head1 SYNOPSIS
 
@@ -255,6 +255,7 @@ This document describes version 0.04_02 of Date::Easy::Date.
     # addition and subtraction work in increments of days
     my $tomorrow = today + 1;
     my $last_week = today - 7;
+    say "$d was ", today - $d, " days ago";
 
     my $yr = $d->year;
     my $mo = $d->month;
@@ -405,6 +406,11 @@ object.  The original date is not modified.
 You can subtract an integer value from a date object.  It subtracts that number of days and returns
 a new date object.  The original date is not modified.
 
+You can subtract one date from another; the result is the number of days you would have to add to
+the right-hand operand to get the left-hand operand (therefore, the result is positive when the
+left-hand side is a later date, and negative when the left-hand side is earlier).  Currently the
+result of attempting to subtract a datetime from a date is undefined.
+
 =head1 BUGS, CAVEATS and NOTES
 
 Because a number like "20090120" can be either a compact datestring (20-Jan-2009) or  a valid number
